==> u61-0.3.2.tar.gz: u61-0.3.2/src/editnumber.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   editnumber.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: A menu item which allows the user to type a number.
 *              this is different from the number item where the number
 *              is chosen with the arrow keys.
 *              Here, one just type the text as if it were a "edit" item
 */



/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#include "editnumber.h"
#include "menuinput.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/* 
 * creation of a 'number edit' item
 */ 
U61_EditNumber::U61_EditNumber(char *label, 
			       int *val, int min_val,int max_val) 
  : U61_Edit(label,NULL)
{ 
  number_value=val;
  min_value=min_val;
  max_value=max_val;

  update();
}

/*--------------------------------------------------------------------------*/
/*
 * callback for key presses
 */
bool U61_EditNumber::action(int key)
{
  bool changed=false;

  if (isdigit(key) || !isalnum(key))
    {
      changed=U61_Edit::action(key);
      *number_value=atoi(value);   
    } 

  return changed;
}

/*--------------------------------------------------------------------------*/
/*
 * updates the text displayed so that it reflects the value of the item
 */
void U61_EditNumber::update()
{
  sprintf(value,"%d",*number_value);
  
  U61_Edit::update();
}

==> u61-0.4.0.tar.gz: u61-0.4.0/src/editnumber.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   editnumber.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: A menu item which allows the user to type a number.
 *              this is different from the number item where the number
 *              is chosen with the arrow keys.
 *              Here, one just type the text as if it were a "edit" item
 */



/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#include "editnumber.h"
#include "menuinput.h"
#include "global.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/* 
 * creation of a 'number edit' item
 */ 
U61_EditNumber::U61_EditNumber(char *label, 
			       int *val, int min_val,int max_val) 
  : U61_Edit(label,NULL)
{ 
  number_value=val;
  min_value=min_val;
  max_value=max_val;

  update();
}

/*--------------------------------------------------------------------------*/
/*
 * callback for key presses
 */
bool U61_EditNumber::action(int key)
{
  bool changed=false;
  int ascii;

  ascii=U61_Global::input_monitor.to_ascii(key);
  if (isdigit(ascii) || !isalnum(ascii))
    {
      changed=U61_Edit::action(key);
      *number_value=atoi(value);   
    } 

  return changed;
}

/*--------------------------------------------------------------------------*/
/*
 * updates the text displayed so that it reflects the value of the item
 */
void U61_EditNumber::update()
{
  sprintf(value,"%d",*number_value);
  
  U61_Edit::update();
}
